/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.connector.core.fileproperties;

import java.util.LinkedList;
import java.util.List;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

public class ConnectorParametersHandler extends DefaultHandler {
  
  private List<ConnectorParameter> parameters;
  private ConnectorParameter currentParameter;
  private boolean inParameter;
  
  public ConnectorParametersHandler() {
    super();
  }
  
  public List<ConnectorParameter> getParameters() {
    return parameters;
  }
  
  public void startElement(String uri, String locaName, String qName,
      Attributes attributes) throws SAXException {
    if(qName.equals("parameters")) {
      parameters = new LinkedList<ConnectorParameter>();
    } else if (qName.equals("parameter")) {
      String setterName = attributes.getValue("setter");
      if (setterName == null) {
        throw new SAXException("the setter attribute is missing");
      }
      String paramType = attributes.getValue("type");
      if (paramType == null) {
        throw new SAXException("the type attribute is missing");
      }
      String paramValue = attributes.getValue("value");
      if (paramValue == null) {
        throw new SAXException("the value attribute is missing");
      }
      inParameter = true;
      currentParameter = new ConnectorParameter();
      currentParameter.setSetterName(setterName);
      currentParameter.setType(paramType);
      currentParameter.setValue(paramValue);
    } else {
        throw new SAXException("Unknown tag: "+qName);
    }
  }

  public void endElement(String uri, String localName, String qName)
  throws SAXException {
    if (qName.equals("parameter") && inParameter) {
      parameters.add(currentParameter);
      currentParameter = null;
      inParameter = false;
    } else if (!qName.equals("parameters")) {
      throw new SAXException("Unknown ending tag: "+qName);
    }
  }
}
