/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.connector.impl.database;

import org.ow2.bonita.connector.core.annotation.Checkbox;
import org.ow2.bonita.connector.core.annotation.Forbidden;
import org.ow2.bonita.connector.core.annotation.Id;
import org.ow2.bonita.connector.core.annotation.Input;
import org.ow2.bonita.connector.core.annotation.Language;
import org.ow2.bonita.connector.core.annotation.Page;
import org.ow2.bonita.connector.core.annotation.Radio;
import org.ow2.bonita.connector.core.annotation.Required;
import org.ow2.bonita.connector.core.annotation.Text;

@Id("HSQLDB")
@Language("org.ow2.bonita.connector.impl.database.HSQLDBConnector")
public class HSQLDBConnector extends RemoteDatabaseConnector {

  private Boolean local = true;
  private Boolean server = false;
  private Boolean webServer = false;
  private Boolean ssl = null;

  public Boolean isLocal() {
    return local;
  }

  public Boolean isServer() {
    return server;
  }

  public Boolean isWebServer() {
    return webServer;
  }

  public Boolean isSsl() {
    return ssl;
  }

  @Input @Required
  @Page(page="db",order=6)
  @Radio(name="mode",value="local")
  public void setLocal(Boolean local) {
    this.local = local;
  }

  @Input @Required
  @Page(page="db",order=7)
  @Radio(name="mode",value="server")
  public void setServer(Boolean server) {
    this.server = server;
  }

  @Input @Required
  @Page(page="db",order=8)
  @Radio(name="mode",value="web")
  public void setWebServer(Boolean webServer) {
    this.webServer = webServer;
  }

  @Input @Forbidden("local")
  @Page(page="db",order=9)
  @Checkbox(name="security",value="ssl")
  public void setSsl(Boolean ssl) {
    this.ssl = ssl;
  }

  @Override @Input @Required("server | webServer") @Forbidden("local")
  @Page(page="db",order=4)
  public void setHostName(String hostName) {
    super.setHostName(hostName);
  }

  @Override @Input @Required("server | webServer") @Forbidden("local")
  @Page(page="db",order=5) @Text(size=5,maxChar=5)
  public void setPort(Integer port) {
    super.setPort(port);
  }

  @Override
  protected String getDriver() {
    return "org.hsqldb.jdbcDriver";
  }

  @Override
  protected String getUrl() {
    StringBuilder builder = new StringBuilder("jdbc:hsqldb:");
    if (isServer()) {
      if (isSsl()) {
        builder.append("hsqls://");
      } else {
        builder.append("hsql://");
      }
      builder.append(getHostName());
      builder.append(":");
      builder.append(getPort());
      builder.append("/");
    } else if (isWebServer()) {
      if (isSsl()) {
        builder.append("https://");
      } else {
        builder.append("http://");
      }
      builder.append(getHostName());
      builder.append(":");
      builder.append(getPort());
      builder.append("/");
    } else {
      builder.append("file:");
    }
    builder.append(getDatabase());
    return builder.toString();
  }
}
