/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.connector.impl.database;

import org.ow2.bonita.connector.core.annotation.Forbidden;
import org.ow2.bonita.connector.core.annotation.Id;
import org.ow2.bonita.connector.core.annotation.Input;
import org.ow2.bonita.connector.core.annotation.Language;
import org.ow2.bonita.connector.core.annotation.Page;
import org.ow2.bonita.connector.core.annotation.Radio;
import org.ow2.bonita.connector.core.annotation.Required;

@Id("Oracle")
@Language("org.ow2.bonita.connector.impl.database.OracleConnector")
public class OracleConnector extends RemoteDatabaseConnector {

  private Boolean oracleSID;
  private Boolean oracleServiceName;
  private Boolean oracleOCI;

  public Boolean isOracleSID() {
    return oracleSID;
  }

  public Boolean isOracleServiceName() {
    return oracleServiceName;
  }

  public Boolean isOracleOCI() {
    return oracleOCI;
  }

  @Input @Required
  @Page(page="db",order=6)
  @Radio(name="type",value="SID")
  public void setOracleSID(Boolean oracleSID) {
    this.oracleSID = oracleSID;
  }

  @Input @Required
  @Page(page="db",order=7)
  @Radio(name="type",value="SN")
  public void setOracleServiceName(Boolean oracleServiceName) {
    this.oracleServiceName = oracleServiceName;
  }

  @Input @Required
  @Page(page="db",order=8)
  @Radio(name="type",value="OCI")
  public void setOracleOCI(Boolean oracleOCI) {
    this.oracleOCI = oracleOCI;
  }

  @Override @Input @Required("oracleSID | oracleServiceName") @Forbidden("oracleOCI")
  @Page(page="db",order=4)
  public void setHostName(String hostName) {
    super.setHostName(hostName);
  }

  @Override @Input @Required("oracleSID | oracleServiceName") @Forbidden("oracleOCI")
  @Page(page="db",order=5)
  public void setPort(Integer port) {
    super.setPort(port);
  }

  @Override
  protected String getDriver() {
    return "oracle.jdbc.driver.OracleDriver";
  }

  @Override
  protected String getUrl() {
    StringBuilder builder = new StringBuilder("jdbc:oracle:");
    if (isOracleSID()) {
      builder.append("thin:@");
      builder.append(getHostName());
      builder.append(":");
      builder.append(getPort());
      builder.append(":");
      builder.append(getDatabase());
    } else if (isOracleServiceName()) {
      builder.append("thin:@(description=(address=(protocol=tcp)(host=");
      builder.append(getHostName());
      builder.append(")(port=");
      builder.append(getPort());
      builder.append("))(connect_data=(service_name=");
      builder.append(getDatabase());
      builder.append(")))");
    } else {
      builder.append("oci8:@");
      builder.append(getDatabase());
    }
    return builder.toString();
  }
}
