/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.connector.impl.database;

import java.util.List;

import org.ow2.bonita.connector.core.ConnectorError;
import org.ow2.bonita.connector.core.annotation.Input;
import org.ow2.bonita.connector.core.annotation.Page;
import org.ow2.bonita.connector.core.annotation.Text;

public abstract class RemoteDatabaseConnector extends SimpleRemoteDatabaseConnector {

  private Integer port;

  public Integer getPort() {
    return port;
  }

  @Input
  @Page(page="db",order=5) @Text(size=5,maxChar=5)
  public void setPort(Integer port) {
    this.port = port;
  }

  public void setPort(Long port) {
    this.port = port.intValue();
  }

  @Override
  protected List<ConnectorError> validateValues() {
    List<ConnectorError> errors = super.validateValues();
    if (getPort() != null) {
      if (this.getPort() < 0) {
        errors.add(new ConnectorError("Port",
            new IllegalArgumentException("cannot be less than 0!")));
      } else if (this.getPort() > 65535) {
        errors.add(new ConnectorError("Port",
            new IllegalArgumentException("cannot be greater than 65535!")));
      }
    }    
    return errors;
  }
}
