/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.connector.impl.email;

import javax.mail.Authenticator;
import javax.mail.PasswordAuthentication;

/**
 * The class SMTPAuthenticator represents an object that knows how
 * to obtain authentication for a network connection with an SMTP server.
 *
 * @author chaffotm
 */
public class SMTPAuthenticator extends Authenticator {
  /**
   * The user name used for authentication.
   */
  private String userName;

  /**
   * The password used for authentication.
   */
  private String pwd;

  /**
   * Create an SMTPAuthenticator.
   * @param username the user name used for authentication.
   * @param password the password used for authentication.
   */
  public SMTPAuthenticator(final String username, final String password) {
    userName = username;
    pwd = password;
  }

  /**
   * Called when password authorization is needed.
   */
  @Override
  public PasswordAuthentication getPasswordAuthentication() {
    return new PasswordAuthentication(userName, pwd);
  }
}
