/**
 * Copyright (C) 2009  BonitaSoft S.A..
 * BonitaSoft, 31 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.connector.impl.mapper;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;
import java.util.Set;

import org.ow2.bonita.connector.core.ConnectorError;
import org.ow2.bonita.connector.core.Mapper;
import org.ow2.bonita.connector.core.annotation.Input;
import org.ow2.bonita.connector.core.annotation.Required;

/**
 * This Mapper chooses N candidates between available candidates
 * @author chaffotm
 *
 */
public class RandomMultipleMapper extends Mapper {

	private Long candidateNumber;

  public Long getCandidateNumber() {
  	return candidateNumber;
  }

  @Input @Required
  public void setCandidateNumber(Long candidateNumber) {
  	this.candidateNumber = candidateNumber;
  }

  @Override
  protected void executeConnector() throws Exception {
  	Long cn = getCandidateNumber().longValue();
  	Random rand = new Random();
  	Set<String> temp = getCandidates();
  	Set<String> members = getMembers();
	  for (long i = 0; i < cn; i++) {
	    int candidatesNb = temp.size();
		  int next = rand.nextInt(candidatesNb);
		  System.out.println(next);
		  String member = get(temp, next);
		  System.out.println(member);
		  members.add(member);
		  temp.remove(member);
    }
  }

  @Override
  protected List<ConnectorError> validateValues() {
  	List<ConnectorError> errors = new ArrayList<ConnectorError>();
  	if (getCandidateNumber() < 1) {
  		 errors.add(new ConnectorError("candidateNumber",
           new IllegalArgumentException("cannot be less than 1")));
  	} else if (getCandidateNumber() > getCandidates().size()) {
  		errors.add(new ConnectorError("candidateNumber",
          new IllegalArgumentException("cannot be greater than the candidates number")));
  	}
	  return errors;
  }
}
