/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.function;

import java.util.List;

import org.ow2.bonita.connector.core.ConnectorError;
import org.ow2.bonita.connector.core.annotation.Id;
import org.ow2.bonita.connector.core.annotation.Input;
import org.ow2.bonita.connector.core.annotation.Language;
import org.ow2.bonita.connector.core.annotation.Page;
import org.ow2.bonita.connector.core.annotation.Required;
import org.ow2.bonita.connector.core.annotation.Textarea;

/**
 * The <code>ConcatStringConnector</code> class wraps the method
 * concat of the <code>String</code> class.
 * So it concatenates two strings. Both Strings cannot be null.
 * @see java.lang.String#concat(String)
 * @author chaffotm
 *
 */
@Id("ConcatString")
@Language("org.ow2.bonita.function.ConcatStringConnector")
public class ConcatStringConnector extends StringConnector {

  /**
   * The String to put at the end of the concatenated String.
   */
  private String end;

  public String getEnd() {
    return end;
  }

  /**
   * Sets the String to put at the end of the concatenated String.
   * @param end the String to put at the end of the concatenated String
   */
  @Input @Required
  @Page(page="str",order=2)
  @Textarea(columns=60,rows=10,maxChar=600,maxCharPerRow=60)
  public void setEnd(final String end) {
    this.end = end;
  }

  @Override
  protected void executeConnector() throws Exception {
    setResult(getString().concat(end));
  }

  @Override
  protected List<ConnectorError> validateValues() {
    return null;
  }
}
