/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.function;

import java.util.List;

import org.ow2.bonita.connector.core.ConnectorError;
import org.ow2.bonita.connector.core.annotation.Id;
import org.ow2.bonita.connector.core.annotation.Input;
import org.ow2.bonita.connector.core.annotation.Language;
import org.ow2.bonita.connector.core.annotation.Page;
import org.ow2.bonita.connector.core.annotation.Required;

/**
 * The <code>ReplaceAllStringConnector</code> class wraps the method
 * replaceAll of the <code>String</code> class.
 * @see java.lang.String#replaceAll(String, String)
 * @author chaffotm
 *
 */
@Id("ReplaceAllString")
@Language("org.ow2.bonita.function.ReplaceAllStringConnector")
public class ReplaceAllStringConnector extends StringConnector {

  private String regex;
  private String replacement;

  public String getRegex() {
    return regex;
  }

  public String getReplacement() {
    return replacement;
  }

  @Input @Required
  @Page(page="str",order=2)
  public void setRegex(String regex) {
    this.regex = regex;
  }

  @Input @Required
  @Page(page="str",order=3)
  public void setReplacement(String replacement) {
    this.replacement = replacement;
  }

  @Override
  protected void executeConnector() throws Exception {
  	setResult(getString().replaceAll(regex, replacement));
  }

  @Override
  protected List<ConnectorError> validateValues() {
    return null;
  }
}
