/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.function;

import java.util.List;

import org.ow2.bonita.connector.core.ConnectorError;
import org.ow2.bonita.connector.core.annotation.Id;
import org.ow2.bonita.connector.core.annotation.Input;
import org.ow2.bonita.connector.core.annotation.Language;
import org.ow2.bonita.connector.core.annotation.Page;
import org.ow2.bonita.connector.core.annotation.Required;
import org.ow2.bonita.connector.core.annotation.Text;

/**
 * The <code>ReplaceStringConnector</code> class wraps the method
 * replace of the <code>String</code> class.
 * @see java.lang.String#replace(CharSequence, CharSequence)
 * @author chaffotm
 *
 */
@Id("ReplaceString")
@Language("org.ow2.bonita.function.ReplaceStringConnector")
public class ReplaceStringConnector extends StringConnector {

  /**
   * The string to be replaced.
   */
  private String target;

  /**
   * The replacement string.
   */
  private String replacement;

  public String getTarget() {
    return target;
  }

  public String getReplacement() {
    return replacement;
  }

  @Input @Required
  @Page(page="str",order=2)
  @Text(size=1,maxChar=1)
  public void setTarget(String target) {
    this.target = target;
  }

  @Input @Required
  @Page(page="str",order=3)
  @Text(size=1,maxChar=1)
  public void setReplacement(String replacement) {
    this.replacement = replacement;
  }

  @Override
  protected void executeConnector() throws Exception {
  	setResult(getString().replace(target, replacement));
  }

  @Override
  protected List<ConnectorError> validateValues() {
    return null;
  }
}
